@@ -3,7 +3,7 @@ BEGIN {
   $POE::Quickie::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Quickie::VERSION = '0.10';
+  $POE::Quickie::VERSION = '0.11';
 }
 
 use strict;
@@ -61,8 +61,6 @@ sub _create_session {
         },
     );
 
-    $self->{got_session} = 1;
-
     return;
 }
 
@@ -77,12 +75,13 @@ sub _start {
 
 sub _stop {
     my $self = $_[OBJECT];
-    $self->{got_session} = 0;
+    delete $self->{session_id};
     return;
 }
 
 sub run {
     my ($self, %args) = @_;
+    $self = POE::Quickie->new() if ref $self ne 'POE::Quickie';
 
     croak 'Program parameter not supplied' if !defined $args{Program};
 
@@ -94,7 +93,7 @@ sub run {
         croak 'AltFork does not currently work on Win32';
     }
 
-    $self->_create_session() if !$self->{got_session};
+    $self->_create_session() if !defined $self->{session_id};
 
     my ($exception, $wheel)
         = $poe_kernel->call($self->{session_id}, '_create_wheel', \%args);
@@ -294,6 +293,7 @@ sub _pid_to_id {
 
 sub killall {
     my $self = shift;
+    $self = POE::Quickie->new() if ref $self ne 'POE::Quickie';
     $poe_kernel->call($self->{session_id}, '_killall', @_);
     return;
 }
@@ -312,6 +312,7 @@ sub _killall {
 
 sub programs {
     my ($self) = @_;
+    $self = POE::Quickie->new() if ref $self ne 'POE::Quickie';
 
     my %wheels;
     for my $id (keys %{ $self->{wheels} }) {
@@ -325,7 +326,7 @@ sub programs {
 sub _lazy_run {
     my ($self, %args) = @_;
 
-    $self->_create_session() if !$self->{got_session};
+    $self->_create_session() if !defined $self->{session_id};
     my $parent_id = $poe_kernel->get_active_session->ID;
     $poe_kernel->refcount_increment($parent_id, __PACKAGE__);
     $poe_kernel->refcount_increment($self->{session_id}, __PACKAGE__);
@@ -419,8 +420,7 @@ POE::Quickie - A lazy way to wrap blocking programs
      print $stdout;
 
      # the more involved interface
-     $self->{quickie} = POE::Quickie->new();
-     $self->{quickie}->run(
+     POE::Quickie->run(
          Program     => ['foo.pl', 'bar'],
          StdoutEvent => 'stdout',
          Context     => 'remember this',
@@ -455,10 +455,11 @@ L<C<quickie_*>|/FUNCTIONS> functions which are exported by default.
 =head2 C<new>
 
 Constructs a POE::Quickie object. You only need to do this if you want to
-be able to call L<C<run>|/run>, L<C<killall>|/killall>, or
-L<C<programs>|/programs>. It is also safe to let go of the object once you're
-done calling its methods. POE::Quickie will continue to run your programs
-until they finish.
+specify any of the parameters below, since a POE::Quickie object will be
+constructed automatically whenever it is needed. The rest of the methods can
+be called on the object (C<< $object->run() >>) or as class methods
+(C<< POE::Quickie->run() >>). You can safely let the object go out of scope;
+POE::Quickie will continue to run your programs until they finish.
 
 Takes 3 optional parameters: B<'debug'>, B<'default'>, and B<'trace'>. These
 will be passed to the object's L<POE::Session|POE::Session> constructor. See
